@@ -30,6 +30,6 @@ public:
 
     void compare(Akonadi::AbstractDifferencesReporter *reporter, const Akonadi::Item &leftItem, const Akonadi::Item &rightItem) override;
 
-    QString extractGid(const Item &item) const override;
+    [[nodiscard]] QString extractGid(const Item &item) const override;
 };
 }
